CKEDITOR.plugins.setLang("docprops","lv",{bgColor:"Fona krāsa",bgFixed:"Fona attēls ir fiksēts",bgImage:"Fona attēla hipersaite",charset:"Simbolu kodējums",charsetASCII:"ASCII",charsetCE:"Centrāleiropas",charsetCR:"Kirilica",charsetCT:"Ķīniešu tradicionālā (Big5)",charsetGR:"Grieķu",charsetJP:"Japāņu",charsetKR:"Korejiešu",charsetOther:"Cits simbolu kodējums",charsetTR:"Turku",charsetUN:"Unikods (UTF-8)",charsetWE:"Rietumeiropas",chooseColor:"Izvēlēties",design:"Dizains",docTitle:"Dokumenta virsraksts <Title>",
docType:"Dokumenta tips",docTypeOther:"Cits dokumenta tips",label:"Dokumenta īpašības",margin:"Lapas robežas",marginBottom:"Apakšā",marginLeft:"Pa kreisi",marginRight:"Pa labi",marginTop:"Augšā",meta:"META dati",metaAuthor:"Autors",metaCopyright:"Autortiesības",metaDescription:"Dokumenta apraksts",metaKeywords:"Dokumentu aprakstoši atslēgvārdi (atdalīti ar komatu)",other:"<cits>",previewHtml:'<p>Šis ir <strong>parauga teksts</strong>. Jūs izmantojiet <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Dokumenta īpašības",txtColor:"Teksta krāsa",xhtmlDec:"Ietvert XHTML deklarācijas"});