/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","ug",{title:"ئىشلەتكۈچى ئارايۈزى رەڭ تاللىغۇچ",preview:"شۇئان ئالدىن كۆزىتىش",config:"بۇ ھەرپ تىزىقىنى config.js ھۆججەتكە چاپلايدۇ",predefined:"ئالدىن بەلگىلەنگەن رەڭلەر"});