CKEDITOR.plugins.setLang("docprops","si",{bgColor:"පසුබිම් වර්ණය",bgFixed:"Non-scrolling (Fixed) Background",bgImage:"පසුබිම් ",charset:"Character Set Encoding",charsetASCII:"ASCII",charsetCE:"මාධ්‍ය ",charsetCR:"සිරිලික් හෝඩිය",charsetCT:"චීන සම්ප්‍රදාය",charsetGR:"ග්‍රීක",charsetJP:"ජපාන",charsetKR:"Korean",charsetOther:"අනෙකුත් අක්ෂර කොටස්",charsetTR:"තුර්කි",charsetUN:"Unicode (UTF-8)",charsetWE:"බස්නාහිර ",chooseColor:"තෝරන්න",design:"Design",docTitle:"පිටු මාතෘකාව",docType:"ලිපිගොනු වර්ගයේ මාතෘකාව",
docTypeOther:"අනෙකුත් ලිපිගොනු වර්ගයේ මාතෘකා",label:"ලිපිගොනු ",margin:"පිටු සීමාවන්",marginBottom:"පහල",marginLeft:"වම",marginRight:"දකුණ",marginTop:"ඉ",meta:"Meta Tags",metaAuthor:"Author",metaCopyright:"ප්‍රකාශන ",metaDescription:"ලිපිගොනු ",metaKeywords:"ලිපිගොනු පෙලගේසමේ විශේෂ වචන (කොමා වලින් වෙන්කරන ලද)",other:"අනෙකුත්",previewHtml:'<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>',title:"පෝරමයේ ගුණ/",txtColor:"අක්ෂර වර්ණ",xhtmlDec:"Include XHTML Declarations"});