CKEDITOR.plugins.setLang("docprops","cs",{bgColor:"Barva pozadí",bgFixed:"Nerolovatelné (Pevné) pozadí",bgImage:"URL obrázku na pozadí",charset:"Znaková sada",charsetASCII:"ASCII",charsetCE:"Středoevropské jazyky",charsetCR:"Cyrilice",charsetCT:"Tradiční čínština (Big5)",charsetGR:"Řečtina",charsetJP:"Japonština",charsetKR:"Korejština",charsetOther:"Další znaková sada",charsetTR:"Turečtina",charsetUN:"Unicode (UTF-8)",charsetWE:"Západoevropské jazyky",chooseColor:"Výběr",design:"Vzhled",docTitle:"Titulek stránky",
docType:"Typ dokumentu",docTypeOther:"Jiný typ dokumetu",label:"Vlastnosti dokumentu",margin:"Okraje stránky",marginBottom:"Dolní",marginLeft:"Levý",marginRight:"Pravý",marginTop:"Horní",meta:"Metadata",metaAuthor:"Autor",metaCopyright:"Autorská práva",metaDescription:"Popis dokumentu",metaKeywords:"Klíčová slova (oddělená čárkou)",other:"<jiný>",previewHtml:'<p>Toto je <strong>ukázkový text</strong>. Používáte <a href="javascript:void(0)">CKEditor</a>.</p>',title:"Vlastnosti dokumentu",txtColor:"Barva textu",
xhtmlDec:"Zahrnout deklarace XHTML"});