CKEDITOR.plugins.setLang("docprops","gl",{bgColor:"Cor do fondo",bgFixed:"Fondo fixo (non se despraza)",bgImage:"URL da imaxe do fondo",charset:"Codificación de caracteres",charsetASCII:"ASCII",charsetCE:"Centro europeo",charsetCR:"Cirílico",charsetCT:"Chinés tradicional (Big5)",charsetGR:"Grego",charsetJP:"Xaponés",charsetKR:"Coreano",charsetOther:"Outra codificación de caracteres",charsetTR:"Turco",charsetUN:"Unicode (UTF-8)",charsetWE:"Europeo occidental",chooseColor:"Escoller",design:"Deseño",
docTitle:"Título da páxina",docType:"Cabeceira do tipo de documento",docTypeOther:"Outra cabeceira do tipo de documento",label:"Propiedades do documento",margin:"Marxes da páxina",marginBottom:"Abaixo",marginLeft:"Esquerda",marginRight:"Dereita",marginTop:"Arriba",meta:"Meta etiquetas",metaAuthor:"Autor",metaCopyright:"Dereito de autoría",metaDescription:"Descrición do documento",metaKeywords:"Palabras clave de indexación do documento (separadas por comas)",other:"Outro...",previewHtml:'<p>Este é un <strong>texto de exemplo</strong>. Vostede esta a empregar o <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Propiedades do documento",txtColor:"Cor do texto",xhtmlDec:"Incluír as declaracións XHTML"});