/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("codesnippet","ko",{button:"코드 스니펫 삽입",codeContents:"코드 본문",emptySnippetError:"코드 스니펫은 빈칸일 수 없습니다.",language:"언어",title:"코드 스니펫",pathName:"코드 스니펫"});