CKEDITOR.plugins.setLang("mathjax","da",{title:"Matematik i TeX",button:"Matematik",dialogInput:"Skriv din TeX her",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX dokumentation",loading:"henter...",pathName:"matematik"});