/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","sv",{abort:"Uppladdning avbruten av användaren.",doneOne:"Filuppladdning lyckades.",doneMany:"Uppladdning av %1 filer lyckades.",uploadOne:"Laddar upp fil ({percentage}%)...",uploadMany:"Laddar upp filer, {current} av {max} färdiga ({percentage}%)..."});