/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","ru",{loadError:"Ошибка при чтении файла",networkError:"Сетевая ошибка при загрузке файла",httpError404:"HTTP ошибка при загрузке файла (404: Файл не найден)",httpError403:"HTTP ошибка при загрузке файла (403: Запрещено)",httpError:"HTTP ошибка при загрузке файла (%1)",noUrlError:"Не определен URL для загрузки файлов",responseError:"Некорректный ответ сервера"});