/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","pt-br",{abort:"Envio cancelado pelo usuário.",doneOne:"Arquivo enviado com sucesso.",doneMany:"Enviados %1 arquivos com sucesso.",uploadOne:"Enviando arquivo({percentage}%)...",uploadMany:"Enviando arquivos, {current} de {max} completos ({percentage}%)..."});