CKEDITOR.plugins.setLang("docprops","el",{bgColor:"Χρώμα Φόντου",bgFixed:"Φόντο Χωρίς Κύλιση (Σταθερό)",bgImage:"Διεύθυνση Εικόνας Φόντου",charset:"Κωδικοποίηση Χαρακτήρων",charsetASCII:"ASCII",charsetCE:"Κεντρικής Ευρώπης",charsetCR:"Κυριλλική",charsetCT:"Παραδοσιακή Κινέζικη (Big5)",charsetGR:"Ελληνική",charsetJP:"Ιαπωνική",charsetKR:"Κορεάτικη",charsetOther:"Άλλη Κωδικοποίηση Χαρακτήρων",charsetTR:"Τουρκική",charsetUN:"Διεθνής (UTF-8)",charsetWE:"Δυτικής Ευρώπης",chooseColor:"Επιλέξτε",design:"Σχεδιασμός",
docTitle:"Τίτλος Σελίδας",docType:"Κεφαλίδα Τύπου Εγγράφου",docTypeOther:"Άλλη Κεφαλίδα Τύπου Εγγράφου",label:"Ιδιότητες Εγγράφου",margin:"Περιθώρια Σελίδας",marginBottom:"Κάτω",marginLeft:"Αριστερά",marginRight:"Δεξιά",marginTop:"Κορυφή",meta:"Μεταδεδομένα",metaAuthor:"Δημιουργός",metaCopyright:"Πνευματικά Δικαιώματα",metaDescription:"Περιγραφή Εγγράφου",metaKeywords:"Λέξεις κλειδιά δείκτες εγγράφου (διαχωρισμός με κόμμα)",other:"Άλλο...",previewHtml:'<p>Αυτό είναι ένα <strong>παραδειγματικό κείμενο</strong>. Χρησιμοποιείτε το <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Ιδιότητες Εγγράφου",txtColor:"Χρώμα Κειμένου",xhtmlDec:"Να Συμπεριληφθούν οι Δηλώσεις XHTML"});