CKEDITOR.plugins.setLang("docprops","fo",{bgColor:"Bakgrundslitur",bgFixed:"Læst bakgrund (rullar ikki)",bgImage:"Leið til bakgrundsmynd (URL)",charset:"Teknsett koda",charsetASCII:"ASCII",charsetCE:"Miðeuropa",charsetCR:"Cyrilliskt",charsetCT:"Kinesiskt traditionelt (Big5)",charsetGR:"Grikst",charsetJP:"Japanskt",charsetKR:"Koreanskt",charsetOther:"Onnur teknsett koda",charsetTR:"Turkiskt",charsetUN:"Unicode (UTF-8)",charsetWE:"Vestureuropa",chooseColor:"Vel",design:"Design",docTitle:"Síðuheiti",
docType:"Dokumentslag yvirskrift",docTypeOther:"Annað dokumentslag yvirskrift",label:"Eginleikar fyri dokument",margin:"Síðubreddar",marginBottom:"Niðast",marginLeft:"Vinstra",marginRight:"Høgra",marginTop:"Ovast",meta:"META-upplýsingar",metaAuthor:"Høvundur",metaCopyright:"Upphavsrættindi",metaDescription:"Dokumentlýsing",metaKeywords:"Dokument index lyklaorð (sundurbýtt við komma)",other:"<annað>",previewHtml:'<p>Hetta er ein <strong>royndartekstur</strong>. Tygum brúka <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Eginleikar fyri dokument",txtColor:"Tekstlitur",xhtmlDec:"Viðfest XHTML deklaratiónir"});