CKEDITOR.plugins.setLang("docprops","fr-ca",{bgColor:"Couleur de fond",bgFixed:"Image fixe sans défilement",bgImage:"Image de fond",charset:"Encodage",charsetASCII:"ACSII",charsetCE:"Europe Centrale",charsetCR:"Cyrillique",charsetCT:"Chinois Traditionnel (Big5)",charsetGR:"Grecque",charsetJP:"Japonais",charsetKR:"Coréen",charsetOther:"Autre encodage",charsetTR:"Turque",charsetUN:"Unicode (UTF-8)",charsetWE:"Occidental",chooseColor:"Sélectionner",design:"Design",docTitle:"Titre de la page",docType:"Type de document",
docTypeOther:"Autre type de document",label:"Propriétés du document",margin:"Marges",marginBottom:"Bas",marginLeft:"Gauche",marginRight:"Droite",marginTop:"Haut",meta:"Méta-données",metaAuthor:"Auteur",metaCopyright:"Copyright",metaDescription:"Description",metaKeywords:"Mots-clés (séparés par des virgules)",other:"Autre...",previewHtml:'<p>Voici un <strong>example de texte</strong>. Vous utilisez <a href="javascript:void(0)">CKEditor</a>.</p>',title:"Propriétés du document",txtColor:"Couleur de caractère",
xhtmlDec:"Inclure les déclarations XHTML"});